@@ -1,9 +1,10 @@
 categories <-function(){
-list(continuous="Models for Continous Dependent Variables",
+list(continuous="Models for Continuous Dependent Variables",
      dichotomous="Models for Dichotomous Dependent Variables",
      ordinal="Models for Ordinal Dependent Variables",
-     bounded="Models for Continous Bounded  Dependent Variables",
+     bounded="Models for Continous Bounded Dependent Variables",
      multinomial="Multinomial Choice Models",
      count="Event Count Models",
-     mixed="Models for Mixed Dependent Variables")
+     mixed="Models for Mixed Dependent Variables",
+     ei="Ecological Inference Models")
 }
