@@ -1,6 +1,8 @@
 describe.gamma<-function(){
-category <- "continuous"
+category <- "bounded"
 description  <- "Gamma Regression for Continuous, Positive Dependent Variables"
+authors <- c()
+year <- 2007
 package <-list(	name 	="stats",
 		version	="0.1"
 		)
@@ -11,5 +13,5 @@ parameters$lambda<-list(equations=c(1,1),
 			expVar=TRUE
 			)
 			
-list(category=category,description=description,package=package,parameters=parameters)
+list(category = category, authors = authors, year = year,description=description,package=package,parameters=parameters)
 }
