@@ -4,7 +4,7 @@ setx.default <- function(object, fn = list(numeric = mean, ordered =
   mc <- match.call()
   if (class(object)[1]=="MI")
     object <- object[[1]]
- 
+
   mode <- function(x){
     tb <- tapply(x, x, length)
     if(is.factor(x))
@@ -88,6 +88,7 @@ setx.default <- function(object, fn = list(numeric = mean, ordered =
     resvars <- all.vars(tt.attr$variables[[1+tt.attr$response]])
   else
     resvars <- NULL
+  opt <- vars[na.omit(pmatch(names(mc), vars))]
   data <- dta[complete.cases(mf), names(dta)%in%vars, drop=FALSE]
   if (!is.null(counter)) {
     if (!any(counter == vars))
@@ -96,24 +97,22 @@ setx.default <- function(object, fn = list(numeric = mean, ordered =
     if(is.numeric(treat)) {
       data[treat==1, names(data)==counter] <- 0
       data[treat==0, names(data)==counter] <- 1
-    }
-    else if(is.factor(treat)) {
+    } else if(is.factor(treat)) {
       lev <- levels(treat)
       if(length(lev)==2) {
         treat <- as.numeric(treat) - 1 
         data[treat==1, names(data)==counter] <- lev[1]
         data[treat==0, names(data)==counter] <- lev[2]
-      }
-      else
+      } else {
         stop("counter only takes a binary variable")
-    }
-    else if(is.logical(treat)) {
+      }
+    } else if(is.logical(treat)) {
       treat <- as.numeric(treat)
       data[treat==1, names(data)==counter] <- FALSE
       data[treat==0, names(data)==counter] <- TRUE
-    }
-    else
+    } else {
       stop("not supported variable type for counter")
+    }
     if(!cond)
       stop("if counter is specified, cond must be TRUE")
   }
@@ -127,8 +126,7 @@ setx.default <- function(object, fn = list(numeric = mean, ordered =
       fn <- NULL
     }
     maxl <- nrow(data)
-  }
-  else if (!is.null(fn)) {
+  } else if (!is.null(fn)) {
     if (is.null(fn$numeric) || !is.function(fn$numeric)) {
       warning("fn$numeric coerced to mean().")
       fn$numeric <- mean
@@ -137,36 +135,44 @@ setx.default <- function(object, fn = list(numeric = mean, ordered =
         identical(mean, fn$ordered)) {
       warning("fn$ordered coreced to median().")
       fn$ordered <- median
-    }
-    else if (identical(min.default, fn$ordered)) 
+    } else if (identical(min.default, fn$ordered)) {
       fn$ordered <- min
-    else if (identical(max.default, fn$ordered)) 
+    } else if (identical(max.default, fn$ordered)) {
       fn$ordered <- max
-    else if (identical(median.default, fn$ordered)) 
-      fn$ordered <- median			
+    } else if (identical(median.default, fn$ordered)) {
+      fn$ordered <- median
+    }
     if (is.null(fn$other) || !is.function(fn$other)) { 
       warning("the only available fn for other is mode.")
       fn$other <- mode
     }
     for (i in 1:ncol(data)) {
-      if (!(colnames(data)[i] %in% resvars)) {
-        if (is.numeric(data[,i]))
-          value <- lapply(list(data[,i]), fn$numeric)[[1]]
-        else if (is.ordered(data[,i])) 
-          value <- lapply(list(data[,i]), fn$ordered)[[1]]
-        else 
-          value <- lapply(list(data[,i]), fn$other)[[1]]
-        data[,i] <- value
+      if (!(colnames(data)[i] %in% opt)) {
+        if (!(colnames(data)[i] %in% resvars)) {
+          if (is.numeric(data[,i]))
+            value <- lapply(list(data[,i]), fn$numeric)[[1]]
+          else if (is.ordered(data[,i])) 
+            value <- lapply(list(data[,i]), fn$ordered)[[1]]
+          else 
+            value <- lapply(list(data[,i]), fn$other)[[1]]
+          data[,i] <- value
+        }
       }
     }
     maxl <- 1
   } else {
     maxl <- nrow(data)
   }
-  opt <- vars[na.omit(pmatch(names(mc), vars))]
   if (length(opt) > 0)
     for (i in 1:length(opt)) {
-      value <- eval(mc[[opt[i]]], envir = env)
+      arg_frame <- 1
+      value <- NULL
+      while((is.null(value) || class(value)=="try-error")
+             && ((arg_frame == 1) || !identical(parent.frame(n=arg_frame-1),.GlobalEnv))){
+        value <- try(eval(mc[[opt[i]]], envir = parent.frame(n=arg_frame)), TRUE)
+        arg_frame <- arg_frame+1
+      }
+      if(class(value)=="try-error") stop(value) 
       lv <- length(value)
       if (lv>1)
         if (maxl==1 || maxl==lv) {
@@ -219,7 +225,7 @@ updatefn <- function(fn, operVec=c("mode", "median","min", "max"), ev=parent.fra
      min   <- get("min", env=ev)
       
      modeG   <- get("mode", env=global)
-     medianG <- get("median", env=global)
+     medianG <- get("median.default", env=global)
      minG <- get("min", env=global)
      maxG <-  get("max", env=global)
     if(!identical(sort(c("max", "median", "min", "mode")), sort(operVec)))
