@@ -1,6 +1,7 @@
 summary.gee.robust <- function(object, ...){
   class(object) <- c("gee", "glm")
-  res <- summary.gee(object,...)
+  ##res <- summary.gee(object,...)
+  res <- summary(object,...)	
   res$coefficients <- res$coefficients[,-5]
   res$coefficients[,2] <- s.err <- sqrt(diag(object$robust.variance))
   res$coefficients[,3] <- zvalue <- coef(object)/s.err
